using System;
using System.ComponentModel;
using Syncfusion.Styles;
using Syncfusion.Windows.Forms.Grid;

namespace FormulaEngineDefect
{
    [Serializable]
    public class SyncStyleProperties : GridStyleInfoCustomProperties
    {
        // static initialization of property descriptors
        static readonly Type t = typeof(SyncStyleProperties);

        readonly static StyleInfoProperty PersonProperty = CreateStyleInfoProperty(t, "Person", StyleInfoPropertyOptions.All);

        // default settings for all properties this object holds
        static readonly SyncStyleProperties defaultObject;

        // initialize default settings for all properties in static ctor
        static SyncStyleProperties()
        {
            // all properties must be initialized for the Default property
            defaultObject = new SyncStyleProperties(GridStyleInfo.Default);
        }

        /// <summary>
        /// Provides access to default values for this type
        /// </summary>
        public static SyncStyleProperties Default
        {
            get
            {
                return defaultObject;
            }
        }

        /// <summary>
        /// Force static ctor being called at least once
        /// </summary>
        public static void Initialize()
        {
        }


        /// <summary>
        /// Explicit cast from GridStyleInfo to this custom propety object
        /// </summary>
        /// <returns>A new custom properties object.</returns>
        public static explicit operator SyncStyleProperties(GridStyleInfo style)
        {
            return new SyncStyleProperties(style);
        }

        /// <summary>
        /// Initializes a SliderStyleProperties object with a style object that holds all data
        /// </summary>
        public SyncStyleProperties(GridStyleInfo style)
            : base(style)
        {
        }

        /// <summary>
        /// Initializes a SyncStyleProperties object with an empty style object. Design
        /// time environment will use this ctor and later copy the values to a style object
        /// by calling style.CustomProperties.Add(gridExcelTipStyleProperties1)
        /// </summary>
        public SyncStyleProperties()
        {
        }

        /// <summary>
        /// Person
        /// </summary>
        [
            Description("Person"),
            Browsable(true),
            Category("Person")
        ]
        public Person Person
        {
            get
            {
                //TraceUtil.TraceCurrentMethodInfo();
                return (Person)style.GetValue(PersonProperty);
            }
            set
            {
                //style.SetValue(PersonProperty, null);
                ////TraceUtil.TraceCurrentMethodInfo(value);
                //if (value != null && value.Value != null)
                //    style.CellValue = value.Value;
                style.SetValue(PersonProperty, value);
            }
        }
        /// <summary>
        /// Resets Minimum state
        /// </summary>
        public void ResetPerson()
        {
            style.ResetValue(PersonProperty);
        }
        [EditorBrowsableAttribute(EditorBrowsableState.Never)]
        private bool ShouldSerializePerson()
        {
            return style.HasValue(PersonProperty);
        }
        /// <summary>
        /// Gets if Minimum state has been initialized for the current object.
        /// </summary>
        [Browsable(false), DesignerSerializationVisibility(DesignerSerializationVisibility.Hidden)]
        public bool HasPerson
        {
            get
            {
                return style.HasValue(PersonProperty);
            }
        }

    }
}